@@ -6,7 +6,6 @@ import json
 Read google sheet as dataframe
 Usage example: read_gsheet("https://sheet.google.com/45qwd3533")
 """
-
 def read_gsheet(url, credentials=None, sheet=None):
 
     import gspread
@@ -40,7 +39,13 @@ Read hubspot contacts as dataframe
 Usage example: read_hubspot_contacts(api_key)
 """
 def read_hubspot_contacts(api_key, offset=100):
-    
     from askdata.integrations import hubspot
+    return hubspot.get_contacts_df(api_key, offset)
 
-    return hubspot.get_contacts(api_key, offset)
\ No newline at end of file
+""" 
+Read alpha vantage api
+Usage example: read_alphavantage_stock(api_key, symbols)
+"""
+def read_alphavantage_stock(symbols, api_key):
+    from askdata.integrations import alphavantage
+    return alphavantage.get_daily_adjusted_df(symbols, api_key)
